import { Grid, Layout } from "antd";
import { SideMenuContent } from "../SideMenu";
import PageContent from "../PageContent";
import { memo, useRef, useState } from "react";
import SideMenuMobile from "../SideMenu/Mobile";
import SideMenuDesktop from "../SideMenu/Desktop";

const { useBreakpoint } = Grid;

const Content = memo(
  ({
    isSideMenuCollapsed,
    setIsSideMenuCollapsed,
    setUserSession,
    userSession,
    contentFirstRender,
  }) => {
    return (
      <SideMenuContent
        isSideMenuCollapsed={isSideMenuCollapsed}
        setIsSideMenuCollapsed={setIsSideMenuCollapsed}
        setUserSession={setUserSession}
        userSession={userSession}
        contentFirstRender={contentFirstRender}
      />
    );
  }
);

export function SideMenu({ isSideMenuCollapsed, setIsSideMenuCollapsed }) {
  const screenBreakpoint = useBreakpoint();

  // used to prevent auto close the sideMenu on mobile on the first render
  const contentFirstRender = useRef(true);

  return (
    <>
      {screenBreakpoint.lg ? (
        <SideMenuDesktop
          isSideMenuCollapsed={screenBreakpoint.lg ? isSideMenuCollapsed : true}
          setIsSideMenuCollapsed={setIsSideMenuCollapsed}
        >
          <Content
            setIsSideMenuCollapsed={setIsSideMenuCollapsed}
            contentFirstRender={contentFirstRender}
          />
        </SideMenuDesktop>
      ) : (
        <SideMenuMobile
          isSideMenuCollapsed={isSideMenuCollapsed}
          setIsSideMenuCollapsed={setIsSideMenuCollapsed}
        >
          <Content
            setIsSideMenuCollapsed={setIsSideMenuCollapsed}
            contentFirstRender={contentFirstRender}
          />
        </SideMenuMobile>
      )}
    </>
  );
}

export default function DashboardLayout({ userSession, setUserSession }) {
  // open on desktop, closed on mobile on page open
  const [isSideMenuCollapsed, setIsSideMenuCollapsed] = useState(
    window.innerWidth < 992
  );

  return (
    <Layout style={{ minHeight: "100vh" }}>
      <Layout>
        <SideMenu
          isSideMenuCollapsed={isSideMenuCollapsed}
          setIsSideMenuCollapsed={setIsSideMenuCollapsed}
        />

        <PageContent
          isSideMenuCollapsed={isSideMenuCollapsed}
          setIsSideMenuCollapsed={setIsSideMenuCollapsed}
          userSession={userSession}
          setUserSession={setUserSession}
        />
      </Layout>
    </Layout>
  );
}
