import { CheckOutlined } from "@ant-design/icons";
import { Spin, Typography } from "antd";
import { useEffect, useRef } from "react";
import { useTranslation } from "react-i18next";

export const RequestState = {
  INIT: -1,
  NOTHING: 0,
  REQUESTING: 1,
  SUCCESS: 2,
  FAILED: 3,
};

export function RequestStateItem({ state, setRequestState }) {
  const { t } = useTranslation();
  const delayTimeout = useRef();

  useEffect(() => {
    if (state === RequestState.SUCCESS) {
      delayTimeout.current = setTimeout(() => {
        setRequestState(RequestState.NOTHING);
      }, 3000);
    }

    return () => {
      if (delayTimeout.current) {
        clearTimeout(delayTimeout.current);
      }
    };
  }, [state]);

  if (state === RequestState.REQUESTING) {
    return <Spin size="small" />;
  }

  if (state === RequestState.SUCCESS) {
    return <CheckOutlined style={{ color: "green" }} />;
  }

  if (state === RequestState.FAILED) {
    return (
      <Typography.Text type="danger">{t("common.failed")}</Typography.Text>
    );
  }

  return <></>;
}
